==> haskell-libyaml-0.1.4-65-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libyaml
version:                0.1.4
visibility:             public
id:                     libyaml-0.1.4-LkHuu4FxRRbCxBpIuF5ofo
key:                    libyaml-0.1.4-LkHuu4FxRRbCxBpIuF5ofo
license:                BSD-3-Clause
maintainer:             Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:              stable
homepage:               https://github.com/snoyberg/yaml#readme
synopsis:               Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>

category:               Text
abi:                    1900b3a082ca142b0efaf465489d6f21
exposed:                True
exposed-modules:        Text.Libyaml
hidden-modules:         Paths_libyaml
import-dirs:            /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs:           /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-libyaml
hs-libraries:           HSlibyaml-0.1.4-LkHuu4FxRRbCxBpIuF5ofo
extra-libraries:        yaml
extra-libraries-static: yaml
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-8OSOdkGtcaZ23KS6p4zYxn
    resourcet-1.2.6-IR3DRlFbTBCF0v7kVv51R

haddock-interfaces:     /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html:           /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libyaml-0.1.4-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libyaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libyaml
version:                0.1.4
visibility:             public
id:                     libyaml-0.1.4-6iKcJTUXZxGDDBL61gPuod
key:                    libyaml-0.1.4-6iKcJTUXZxGDDBL61gPuod
license:                BSD-3-Clause
maintainer:             Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:              stable
homepage:               https://github.com/snoyberg/yaml#readme
synopsis:               Low-level, streaming YAML interface.
description:
    README and API documentation are available at <https://www.stackage.org/package/libyaml>

category:               Text
abi:                    2c12705939810f56bf5a4c5d52fb27f1
exposed:                True
exposed-modules:        Text.Libyaml
hidden-modules:         Paths_libyaml
import-dirs:            /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs:           /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/libyaml-0.1.4
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-libyaml
hs-libraries:           HSlibyaml-0.1.4-6iKcJTUXZxGDDBL61gPuod
extra-libraries:        yaml
extra-libraries-static: yaml
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-8DaA0acFUeIAhiI07RCEeo
    resourcet-1.2.6-ImDiK8j9yhy8AYzQhyOU1O

haddock-interfaces:     /usr/share/doc/haskell-libyaml/html/libyaml.haddock
haddock-html:           /usr/share/doc/haskell-libyaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
